@@ -1,6 +1,10 @@
+import json
+import logging
 from typing import Iterable, List
 from boto3 import client
 
+logger = logging.getLogger(__name__)
+
 
 class Fetcher:
     """
@@ -27,6 +31,8 @@ class Fetcher:
                 item['Value'] = self.__parse_value(item['Value'], item['Type'])
                 items[item['Name']] = item
 
+        logger.info(f'Fetched parameters: {json.dumps(items)}.')
+
         return items, invalid_names
 
     @staticmethod
